<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>GeoServiceProviderFactoryEsri</name>
    <message>
        <source>Esri plugin requires a &apos;esri.token&apos; parameter.
Please visit https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</source>
        <translation>Модуль Esri требует параметр «esri.token».
Посетите https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
    </message>
</context>
<context>
    <name>PlaceSearchReplyEsri</name>
    <message>
        <source>Response parse error</source>
        <translation>Ошибка разбора ответа</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoMap</name>
    <message>
        <source>No Map</source>
        <translation>Нет карты</translation>
    </message>
    <message>
        <source>Plugin does not support mapping.</source>
        <translation>Модуль не поддерживает картографию.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoRouteModel</name>
    <message>
        <source>Plugin does not support routing.</source>
        <translation>Модуль не поддерживает навигацию.</translation>
    </message>
    <message>
        <source>Cannot route, plugin not set.</source>
        <translation>Навигация невозможна, модуль не задан.</translation>
    </message>
    <message>
        <source>Cannot route, route manager not set.</source>
        <translation>Навигация невозможна, навигатор не задан.</translation>
    </message>
    <message>
        <source>Cannot route, valid query not set.</source>
        <translation>Навигация невозможна, верный запрос не задан.</translation>
    </message>
    <message>
        <source>Not enough waypoints for routing.</source>
        <translation>Недостаточно контрольных точек для навигации.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeocodeModel</name>
    <message>
        <source>Cannot geocode, plugin not set.</source>
        <translation>Не удалось определить координаты, модуль не задан.</translation>
    </message>
    <message>
        <source>Cannot geocode, geocode manager not set.</source>
        <translation>Не удалось определить координаты, менеджер координат не задан.</translation>
    </message>
    <message>
        <source>Cannot geocode, valid query not set.</source>
        <translation>Не удалось определить координаты, не указан верный запрос.</translation>
    </message>
    <message>
        <source>Plugin does not support (reverse) geocoding.</source>
        <translation>Модуль не поддерживает (обратное) определение координат.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeNavigator</name>
    <message>
        <source>Plugin does not support navigation.</source>
        <translation>Модуль не поддерживает навигацию.</translation>
    </message>
    <message>
        <source>Failed to create a navigator object.</source>
        <translation>Не удалось создать объект navigator.</translation>
    </message>
</context>
<context>
    <name>QGeoCodeReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Ошибка разбора ответа</translation>
    </message>
</context>
<context>
    <name>QGeoMapMapboxGL</name>
    <message>
        <source>Development access token, do not use in production.</source>
        <translation>Токен доступа разработчика, не использовать в релизе.</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineItemsOverlay</name>
    <message>
        <source>Empty Map</source>
        <translation>Пустая карта</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineMapboxGL</name>
    <message>
        <source>China Streets</source>
        <translation>Китайские улицы</translation>
    </message>
    <message>
        <source>China Light</source>
        <translation>Китайский светлый</translation>
    </message>
    <message>
        <source>China Dark</source>
        <translation>Китайский тёмный</translation>
    </message>
    <message>
        <source>Streets</source>
        <translation>Схема</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Базовый</translation>
    </message>
    <message>
        <source>Bright</source>
        <translation>Яркий</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <translation>На улице</translation>
    </message>
    <message>
        <source>Satellite</source>
        <translation>Спутник</translation>
    </message>
    <message>
        <source>Satellite Streets</source>
        <translation>Спутник+Схема</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светлый</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темный</translation>
    </message>
    <message>
        <source>Navigation Preview Day</source>
        <translation>Предпросмотр навигации днём</translation>
    </message>
    <message>
        <source>Navigation Preview Night</source>
        <translation>Предпросмотр навигации ночью</translation>
    </message>
    <message>
        <source>Navigation Guidance Day</source>
        <translation>Подсказки навигации днём</translation>
    </message>
    <message>
        <source>Navigation Guidance Night</source>
        <translation>Подсказки навигации ночью</translation>
    </message>
    <message>
        <source>User provided style</source>
        <translation>Стиль пользователя</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV4</name>
    <message>
        <source>Go straight.</source>
        <translation>Следуйте прямо.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Следуйте прямо на %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Возьмите правее.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Возьмите правее на %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Поверните направо.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Поверните направо на %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Крутой поворот направо.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Крутой поворот направо на %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>По возможности развернитесь.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Крутой поворот налево.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Крутой поворот налево на %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Поверните налево.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Поверните налево на %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Возьмите левее.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Возьмите левее на %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Достигнута промежуточная точка маршрута.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Продолжайте движение.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Продолжайте движение на %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>Въезжайте на кольцо.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Первый съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Первый съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Второй съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Второй съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Третий съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Третий съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Четвёртый съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Четвёртый съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Пятый съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Пятый съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Шестой съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Шестой съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Седьмой съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Седьмой съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Восьмой съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Восьмой съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Девятый съезд с кольца.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Девятый съезд с кольца на %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Съезжайте с кольца.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Съезжайте с кольца на %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Оставайтесь на кольце.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Начало в конце улицы.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Начало в конце %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Вы добрались до места назначения.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Не знаю, что сказать про «%1»</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV5</name>
    <message>
        <source>North</source>
        <extracomment>Translations exist at https://github.com/Project-OSRM/osrm-text-instructions. Always used in &quot;Head %1 [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>Север</translation>
    </message>
    <message>
        <source>East</source>
        <translation>Восток</translation>
    </message>
    <message>
        <source>South</source>
        <translation>Юг</translation>
    </message>
    <message>
        <source>West</source>
        <translation>Запад</translation>
    </message>
    <message>
        <source>first</source>
        <comment>roundabout exit</comment>
        <extracomment>always used in &quot; and take the %1 exit [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>первый</translation>
    </message>
    <message>
        <source>second</source>
        <comment>roundabout exit</comment>
        <translation>второй</translation>
    </message>
    <message>
        <source>third</source>
        <comment>roundabout exit</comment>
        <translation>третий</translation>
    </message>
    <message>
        <source>fourth</source>
        <comment>roundabout exit</comment>
        <translation>четвёртый</translation>
    </message>
    <message>
        <source>fifth</source>
        <comment>roundabout exit</comment>
        <translation>пятый</translation>
    </message>
    <message>
        <source>sixth</source>
        <comment>roundabout exit</comment>
        <translation>шестой</translation>
    </message>
    <message>
        <source>seventh</source>
        <comment>roundabout exit</comment>
        <translation>седьмой</translation>
    </message>
    <message>
        <source>eighth</source>
        <comment>roundabout exit</comment>
        <translation>восьмой</translation>
    </message>
    <message>
        <source>ninth</source>
        <comment>roundabout exit</comment>
        <translation>девятый</translation>
    </message>
    <message>
        <source>tenth</source>
        <comment>roundabout exit</comment>
        <translation>десятый</translation>
    </message>
    <message>
        <source>eleventh</source>
        <comment>roundabout exit</comment>
        <translation>одиннадцатый</translation>
    </message>
    <message>
        <source>twelfth</source>
        <comment>roundabout exit</comment>
        <translation>двенадцатый</translation>
    </message>
    <message>
        <source>thirteenth</source>
        <comment>roundabout exit</comment>
        <translation>тринадцатый</translation>
    </message>
    <message>
        <source>fourteenth</source>
        <comment>roundabout exit</comment>
        <translation>четырнадцатый</translation>
    </message>
    <message>
        <source>fifteenth</source>
        <comment>roundabout exit</comment>
        <translation>пятнадцатый</translation>
    </message>
    <message>
        <source>sixteenth</source>
        <comment>roundabout exit</comment>
        <translation>шестнадцатый</translation>
    </message>
    <message>
        <source>seventeenth</source>
        <comment>roundabout exit</comment>
        <translation>семнадцатый</translation>
    </message>
    <message>
        <source>eighteenth</source>
        <comment>roundabout exit</comment>
        <translation>восемнадцатый</translation>
    </message>
    <message>
        <source>nineteenth</source>
        <comment>roundabout exit</comment>
        <translation>девятнадцатый</translation>
    </message>
    <message>
        <source>twentieth</source>
        <comment>roundabout exit</comment>
        <translation>двадцатый</translation>
    </message>
    <message>
        <source> and take the %1 exit</source>
        <extracomment>Always appended to one of the following strings: - &quot;Enter the roundabout&quot; - &quot;Enter the rotary&quot; - &quot;Enter the rotary &lt;rotaryname&gt;&quot;</extracomment>
        <translation> %1 съезд с кольца</translation>
    </message>
    <message>
        <source> and take the %1 exit onto %2</source>
        <translation> %1 съезд с кольца на %2</translation>
    </message>
    <message>
        <source>You have arrived at your destination, straight ahead</source>
        <translation>Вы прибыли в пункт назначения, он перед вами</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the left</source>
        <translation>Вы прибыли в пункт назначения, он слева</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the right</source>
        <translation>Вы прибыли в пункт назначения, он справа</translation>
    </message>
    <message>
        <source>You have arrived at your destination</source>
        <translation>Вы прибыли в пункт назначения</translation>
    </message>
    <message>
        <source>Continue straight</source>
        <translation>Продолжайте движение прямо</translation>
    </message>
    <message>
        <source>Continue straight on %1</source>
        <translation>Продолжайте движение прямо по %1</translation>
    </message>
    <message>
        <source>Continue left</source>
        <translation>Продолжайте движение налево</translation>
    </message>
    <message>
        <source>Continue left onto %1</source>
        <translation>Продолжайте движение налево на %1</translation>
    </message>
    <message>
        <source>Continue slightly left</source>
        <translation>Продолжайте движение левее</translation>
    </message>
    <message>
        <source>Continue slightly left on %1</source>
        <translation>Продолжайте движение левее по %1</translation>
    </message>
    <message>
        <source>Continue right</source>
        <translation>Продолжайте движение направо</translation>
    </message>
    <message>
        <source>Continue right onto %1</source>
        <translation>Продолжайте движение направо на %1</translation>
    </message>
    <message>
        <source>Continue slightly right</source>
        <translation>Продолжайте движение правее</translation>
    </message>
    <message>
        <source>Continue slightly right on %1</source>
        <translation>Продолжайте движение правее по %1</translation>
    </message>
    <message>
        <source>Make a U-turn</source>
        <translation>Развернитесь</translation>
    </message>
    <message>
        <source>Make a U-turn onto %1</source>
        <translation>Развернитесь на %1</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжайте движение</translation>
    </message>
    <message>
        <source>Continue on %1</source>
        <translation>Продолжайте движение по %1</translation>
    </message>
    <message>
        <source>Head %1</source>
        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
        <translation>Направляйтесь на %1</translation>
    </message>
    <message>
        <source>Head %1 onto %2</source>
        <translation>Направляйтесь на %1 на %2</translation>
    </message>
    <message>
        <source>Depart</source>
        <translation>Отправляйтесь</translation>
    </message>
    <message>
        <source>Depart onto %1</source>
        <translation>Отправляйтесь по %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn left</source>
        <translation>В конце дороги поверните налево</translation>
    </message>
    <message>
        <source>At the end of the road, turn left onto %1</source>
        <translation>В конце дороги поверните налево на %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn right</source>
        <translation>В конце дороги поверните направо</translation>
    </message>
    <message>
        <source>At the end of the road, turn right onto %1</source>
        <translation>В конце дороги поверните направо на %1</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn</source>
        <translation>Развернитесь в конце дороги</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn onto %1</source>
        <translation>Развернитесь в конце дороги на %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight</source>
        <translation>В конце дороги продолжайте движение прямо</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight onto %1</source>
        <translation>В конце дороги продолжайте движение прямо на %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue</source>
        <translation>В конце дороги продолжайте движение</translation>
    </message>
    <message>
        <source>At the end of the road, continue onto %1</source>
        <translation>В конце дороги продолжайте движение на %1</translation>
    </message>
    <message>
        <source>Take the ferry</source>
        <translation>Погрузитесь на паром</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left</source>
        <translation>На развилке резко поверните налево</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left onto %1</source>
        <translation>На развилке резко поверните налево на %1</translation>
    </message>
    <message>
        <source>At the fork, turn left</source>
        <translation>На развилке поверните налево</translation>
    </message>
    <message>
        <source>At the fork, turn left onto %1</source>
        <translation>На развилке поверните налево на %1</translation>
    </message>
    <message>
        <source>At the fork, keep left</source>
        <translation>На развилке держитесь левее</translation>
    </message>
    <message>
        <source>At the fork, keep left onto %1</source>
        <translation>На развилке держитесь левее на %1</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right</source>
        <translation>На развилке резко поверните направо</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right onto %1</source>
        <translation>На развилке резко поверните направо на %1</translation>
    </message>
    <message>
        <source>At the fork, turn right</source>
        <translation>На развилке поверните направо</translation>
    </message>
    <message>
        <source>At the fork, turn right onto %1</source>
        <translation>На развилке поверните направо на %1</translation>
    </message>
    <message>
        <source>At the fork, keep right</source>
        <translation>На развилке держитесь правее</translation>
    </message>
    <message>
        <source>At the fork, keep right onto %1</source>
        <translation>На развилке держитесь правее на %1</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead</source>
        <translation>На развилке продолжайте движение прямо</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead onto %1</source>
        <translation>На развилке продолжайте движение прямо на %1</translation>
    </message>
    <message>
        <source>At the fork, continue</source>
        <translation>На развилке продолжайте движение</translation>
    </message>
    <message>
        <source>At the fork, continue onto %1</source>
        <translation>На развилке продолжайте движение на %1</translation>
    </message>
    <message>
        <source>Merge sharply left</source>
        <translation>Быстро перестройтесь налево</translation>
    </message>
    <message>
        <source>Merge sharply left onto %1</source>
        <translation>Быстро перестройтесь налево на %1</translation>
    </message>
    <message>
        <source>Merge left</source>
        <translation>Перестройтесь левее</translation>
    </message>
    <message>
        <source>Merge left onto %1</source>
        <translation>Перестройтесь левее на %1</translation>
    </message>
    <message>
        <source>Merge slightly left</source>
        <translation>Перестройтесь немного левее</translation>
    </message>
    <message>
        <source>Merge slightly left on %1</source>
        <translation>Перестройтесь немного левее на %1</translation>
    </message>
    <message>
        <source>Merge sharply right</source>
        <translation>Быстро перестройтесь направо</translation>
    </message>
    <message>
        <source>Merge sharply right onto %1</source>
        <translation>Быстро перестройтесь направо на %1</translation>
    </message>
    <message>
        <source>Merge right</source>
        <translation>Перестройтесь правее</translation>
    </message>
    <message>
        <source>Merge right onto %1</source>
        <translation>Перестройтесь правее на %1</translation>
    </message>
    <message>
        <source>Merge slightly right</source>
        <translation>Перестройтесь немного правее</translation>
    </message>
    <message>
        <source>Merge slightly right on %1</source>
        <translation>Перестройтесь немного правее на %1</translation>
    </message>
    <message>
        <source>Merge straight</source>
        <translatorcomment>Бред какой-то</translatorcomment>
        <translation>Перестройтесь прямо</translation>
    </message>
    <message>
        <source>Merge straight on %1</source>
        <translation>Перестройтесь прямо на %1</translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Перестройтесь</translation>
    </message>
    <message>
        <source>Merge onto %1</source>
        <translation>Перестройтесь на %1</translation>
    </message>
    <message>
        <source>Take a sharp left</source>
        <translation>Крутой поворот налево</translation>
    </message>
    <message>
        <source>Take a sharp left onto %1</source>
        <translation>Крутой поворот налево на %1</translation>
    </message>
    <message>
        <source>Turn left</source>
        <translation>Поверните налево</translation>
    </message>
    <message>
        <source>Turn left onto %1</source>
        <translation>Поверните налево на %1</translation>
    </message>
    <message>
        <source>Continue slightly left onto %1</source>
        <translation>Продолжайте движение левее на %1</translation>
    </message>
    <message>
        <source>Take a sharp right</source>
        <translation>Крутой поворот направо</translation>
    </message>
    <message>
        <source>Take a sharp right onto %1</source>
        <translation>Крутой поворот направо на %1</translation>
    </message>
    <message>
        <source>Turn right</source>
        <translation>Поверните направо</translation>
    </message>
    <message>
        <source>Turn right onto %1</source>
        <translation>Поверните направо на %1</translation>
    </message>
    <message>
        <source>Continue slightly right onto %1</source>
        <translation>Продолжайте движение правее на %1</translation>
    </message>
    <message>
        <source>Continue straight onto %1</source>
        <translation>Продолжайте движение прямо на %1</translation>
    </message>
    <message>
        <source>Continue onto %1</source>
        <translation>Продолжайте движение на %1</translation>
    </message>
    <message>
        <source>Continue on the left</source>
        <translation>Продолжайте движение налево</translation>
    </message>
    <message>
        <source>Continue on the left on %1</source>
        <translation>Продолжайте движение налево на %1</translation>
    </message>
    <message>
        <source>Continue on the right</source>
        <translation>Продолжайте движение направо</translation>
    </message>
    <message>
        <source>Continue on the right on %1</source>
        <translation>Продолжайте движение направо на %1</translation>
    </message>
    <message>
        <source>Take the ramp on the left</source>
        <translation>Сверните на левый съезд</translation>
    </message>
    <message>
        <source>Take the ramp on the left onto %1</source>
        <translation>Сверните на левый съезд на %1</translation>
    </message>
    <message>
        <source>Take the ramp on the right</source>
        <translation>Сверните на правый съезд</translation>
    </message>
    <message>
        <source>Take the ramp on the right onto %1</source>
        <translation>Сверните на правый съезд на %1</translation>
    </message>
    <message>
        <source>Take the ramp</source>
        <translation>Сверните на съезд</translation>
    </message>
    <message>
        <source>Take the ramp onto %1</source>
        <translation>Сверните на съезд на %1</translation>
    </message>
    <message>
        <source>Get off the bike and push</source>
        <translation>Слезьте с велосипеда и толкайте его</translation>
    </message>
    <message>
        <source>Get off the bike and push onto %1</source>
        <translation>Слезьте с велосипеда и толкайте его на %1</translation>
    </message>
    <message>
        <source>Enter the rotary</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Въезжайте на круговую развязку</translation>
    </message>
    <message>
        <source>Enter the roundabout</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Въезжайте на круг</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight</source>
        <translation>На круге продолжайте движение прямо</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight on %1</source>
        <translation>На круге продолжайте движение прямо по %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn left</source>
        <translation>На круге поверните налево</translation>
    </message>
    <message>
        <source>At the roundabout, turn left onto %1</source>
        <translation>На круге поверните налево на %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn right</source>
        <translation>На круге поверните направо</translation>
    </message>
    <message>
        <source>At the roundabout, turn right onto %1</source>
        <translation>На круге поверните направо на %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn around</source>
        <translation>Развернитесь на круге</translation>
    </message>
    <message>
        <source>At the roundabout, turn around onto %1</source>
        <translation>Развернитесь на круге на %1</translation>
    </message>
    <message>
        <source>At the roundabout, continue</source>
        <translation>Продолжайте движение по кругу</translation>
    </message>
    <message>
        <source>At the roundabout, continue onto %1</source>
        <translation>Продолжайте движение по кругу на %1</translation>
    </message>
    <message>
        <source>Take the train</source>
        <translation>Сядьте в поезд</translation>
    </message>
    <message>
        <source>Take the train [%1]</source>
        <translation>Сядьте в поезд [%1]</translation>
    </message>
    <message>
        <source>Go straight</source>
        <translation>Следуйте прямо</translation>
    </message>
    <message>
        <source>Go straight onto %1</source>
        <translation>Следуйте прямо на %1</translation>
    </message>
    <message>
        <source>Turn slightly left</source>
        <translation>Возьмите левее</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1</source>
        <translation>Возьмите левее на %1</translation>
    </message>
    <message>
        <source>Turn slightly right</source>
        <translation>Возьмите правее</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1</source>
        <translation>Возьмите правее на %1</translation>
    </message>
    <message>
        <source>Turn</source>
        <translation>Поверните</translation>
    </message>
    <message>
        <source>Turn onto %1</source>
        <translation>Поверните на %1</translation>
    </message>
    <message>
        <source> and continue straight</source>
        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
        <translation> и продолжайте движение прямо</translation>
    </message>
    <message>
        <source> and continue straight onto %1</source>
        <translation> и продолжайте движение прямо на %1</translation>
    </message>
    <message>
        <source> and make a sharp left</source>
        <translation> и резко поверните налево</translation>
    </message>
    <message>
        <source> and make a sharp left onto %1</source>
        <translation> и резко поверните налево на %1</translation>
    </message>
    <message>
        <source> and turn left</source>
        <translation> и поверните налево</translation>
    </message>
    <message>
        <source> and turn left onto %1</source>
        <translation> и поверните налево на %1</translation>
    </message>
    <message>
        <source> and make a slight left</source>
        <translation> и возьмите левее</translation>
    </message>
    <message>
        <source> and make a slight left onto %1</source>
        <translation> и возьмите левее на %1</translation>
    </message>
    <message>
        <source> and make a sharp right</source>
        <translation> и резко поверните направо</translation>
    </message>
    <message>
        <source> and make a sharp right onto %1</source>
        <translation> и резко поверните направо на %1</translation>
    </message>
    <message>
        <source> and turn right</source>
        <translation> и поверните направо</translation>
    </message>
    <message>
        <source> and turn right onto %1</source>
        <translation> и поверните направо на %1</translation>
    </message>
    <message>
        <source> and make a slight right</source>
        <translation> и возьмите правее</translation>
    </message>
    <message>
        <source> and make a slight right onto %1</source>
        <translation> и возьмите правее на %1</translation>
    </message>
    <message>
        <source> and make a U-turn</source>
        <translation> и развернитесь</translation>
    </message>
    <message>
        <source> and make a U-turn onto %1</source>
        <translation> и развернитесь на %1</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires a &apos;mapbox.access_token&apos; parameter.
Please visit https://www.mapbox.com</source>
        <translation>Модулю Mapbox требуется параметр «mapbox.access_token».
Посетите https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>Менеджер картографии больше не существует</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Street</source>
        <extracomment>Noun describing map type &apos;Street map&apos;</extracomment>
        <translation>Схема</translation>
    </message>
    <message>
        <source>Light</source>
        <extracomment>Noun describing type of a map using light colors (weak contrast)</extracomment>
        <translation>Светлая</translation>
    </message>
    <message>
        <source>Dark</source>
        <extracomment>Noun describing type of a map using dark colors</extracomment>
        <translation>Темная</translation>
    </message>
    <message>
        <source>Satellite</source>
        <extracomment>Noun describing type of a map created by satellite</extracomment>
        <translation>Спутниковая</translation>
    </message>
    <message>
        <source>Streets Satellite</source>
        <extracomment>Noun describing type of a street map created by satellite</extracomment>
        <translation>Спутник+Схема</translation>
    </message>
    <message>
        <source>Wheatpaste</source>
        <extracomment>Noun describing type of a map using wheat paste colors</extracomment>
        <translatorcomment>Как перевести не знаю. Буквальный перевод &quot;Клейстер&quot;.</translatorcomment>
        <translation>Wheatpaste</translation>
    </message>
    <message>
        <source>Streets Basic</source>
        <extracomment>Noun describing type of a basic street map</extracomment>
        <translation>Стандартная</translation>
    </message>
    <message>
        <source>Comic</source>
        <extracomment>Noun describing type of a map using cartoon-style fonts</extracomment>
        <translation>Комическая</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <extracomment>Noun describing type of a map for outdoor activities</extracomment>
        <translation>Уличная</translation>
    </message>
    <message>
        <source>Run Bike Hike</source>
        <extracomment>Noun describing type of a map for sports</extracomment>
        <translation>Спортивная</translation>
    </message>
    <message>
        <source>Pencil</source>
        <extracomment>Noun describing type of a map drawn by pencil</extracomment>
        <translation>В карандаше</translation>
    </message>
    <message>
        <source>Pirates</source>
        <extracomment>Noun describing type of a treasure map with pirate boat watermark</extracomment>
        <translation>Пиратская</translation>
    </message>
    <message>
        <source>Emerald</source>
        <extracomment>Noun describing type of a map using emerald colors</extracomment>
        <translation>Изумрудная</translation>
    </message>
    <message>
        <source>High Contrast</source>
        <extracomment>Noun describing type of a map with high contrast</extracomment>
        <translation>Высококонтрастная</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Карта улиц</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Стандартный дневной вид карты</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Спутниковая карта</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Дневной вид со спутника</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Топографическая карта</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Дневная топографическая карта</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Гибридная карта</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Дневная спутниковая карта со схемой улиц</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Схема транспорта</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Дневная бесцветная схема общественного транстпорта</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Черно-белая карта улиц</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Дневная бесцветная карта</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Мобильная карта улиц</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Дневная мобильная карта улиц</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Мобильная топографическая карта</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Дневная мобильная топографическая карта</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Мобильная гибридная карта</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Дневная мобильная спутниковая карта со схемой улиц</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Мобильная схема транспорта</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Дневная мобильная бесцветная схема общественного транстпорта</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Мобильная бесцветная карта улиц</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Дневная мобильная бесцветная карта</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Особая карта улиц</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Ночная карта улиц</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Стандартный ночной вид карты</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Ночная мобильная карта улиц</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Ночная мобильная карта улиц</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Ночная бесцветная карта улиц</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Ночная бесцветная карта (используется в качестве фоновой карты)</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Ночная бесцветная мобильная карта улиц</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Ночная бесцветная мобильная карта (используется в качестве фоновой карты)</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Пешеходная карта улиц</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Дневная пешеходная карта</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Мобильная пешеходная карта улиц</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Дневная мобильная пешеходная карта улиц</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Ночная пешеходная карта</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Ночная мобильная пешеходная карта улиц</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Ночная мобильная пешеходная карта</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Ночная пешеходная карта улиц</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Навигационная автомобильная карта</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Стандартный дневной вид навигационной карты</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Карта улиц</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Дневная карта улиц</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Дневной вид со спутника</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Велосипедная карта</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Дневная велосипедная карта</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Схема транспорта</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Дневная схема движения общественного транспорта</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Ночная схема транспорта</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Ночная схема движения общественного транспорта</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Топографическая карта</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Топографическая карта</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Туристическая карта</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Туристическая карта</translation>
    </message>
    <message>
        <source>Custom URL Map</source>
        <translation>Особый URL карты</translation>
    </message>
    <message>
        <source>Custom url map view set via urlprefix parameter</source>
        <translation>Задан особая карта по URL через пераметр urlprefix</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Спутниковая карта</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Аэродром</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Стоянка</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Строение</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Магистраль</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Историческое</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Использование</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Досуг</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Искусственное</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Природа</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Место</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Железная дорога</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Магазин</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Туризм</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Водоём</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Ошибка сетевого запроса</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Ошибка разбора ответа</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Response parse error</source>
        <translation>Ошибка разбора ответа</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchSuggestionReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Ошибка разбора ответа</translation>
    </message>
</context>
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Qt Location requires app_id and token parameters.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>Qt Location требуются параметры app_id и token.
Зарегистрируйтесь на https://developer.here.com/, чтобы получить персональные реквизиты.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>Сохранения мест не поддерживается.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>Удаление мест не поддерживается.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>Сохранение категорий не поддерживается.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>Удаление категорий неподдерживается.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Ошибка разбора ответа.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Ошибка сети.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>Запрос был отменён.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>Ответ сервиса имеет неподдерживаемый формат.</translation>
    </message>
    <message>
        <source>Plugin property is not set.</source>
        <translation>Свойство Plugin не задано.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Ошибка модуля (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Ошибка модуля (%1): Не удалось создать провайдера</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>Неверный модуль</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>Не удалось инициализировать категории</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>Не удалось создать запрос</translation>
    </message>
    <message>
        <source>Index &apos;%1&apos; out of range</source>
        <translation>Индекс «%1» вышел за границу</translation>
    </message>
</context>
</TS>
